==> sthali-crud-0.0.3.tar.gz: sthali-crud-0.0.3/README.md <==
# sthali-crud

<p align="center">
    <a href="https://pypi.org/project/sthali-crud" target="_blank">
        <img src="https://img.shields.io/pypi/v/sthali-crud?&label=Version" alt="Package version">
    </a>
    <a href="https://pypi.org/project/sthali-crud" target="_blank">
        <img src="https://img.shields.io/pypi/pyversions/sthali-crud.svg?&label=Python" alt="Supported Python versions">
    </a>
    <a href="https://pypi.org/project/sthali-crud" target="_blank">
        <img src="https://img.shields.io/github/license/jhunufernandes/sthali-crud?&label=License" alt="License">
    </a>
    <a href="https://github.com/jhunufernandes/sthali-crud/actions/workflows/test-package.yml" target="_blank">
        <img src="https://github.com/jhunufernandes/sthali-crud/actions/workflows/test-package.yml/badge.svg" alt="Tests">
    </a>
    <a href="https://github.com/jhunufernandes/sthali-crud/actions/workflows/upload-package.yml" target="_blank">
        <img src="https://github.com/jhunufernandes/sthali-crud/actions/workflows/upload-package.yml/badge.svg" alt="Build">
    </a>
</p>


---

**PyPI**: <a href="https://pypi.org/project/sthali-crud/" target="_blank">https://pypi.org/project/sthali-crud/</a>

**Source Code**: <a href="https://github.com/jhunufernandes/sthali-crud" target="_blank">https://github.com/jhunufernandes/sthali-crud</a>

**Sthali Board**: <a href="https://github.com/users/jhunufernandes/projects/4" target="_blank">https://github.com/users/jhunufernandes/projects/4</a>

---

## Requirements

Python 3.11+

* <a href="https://fastapi.tiangolo.com/" class="external-link" target="_blank">FastAPI</a>
* <a href="https://tinydb.readthedocs.io/" class="external-link" target="_blank">TinyDB</a>

## Installation

<div class="termy">

```console
$ pip install sthali-crud
```

## Configuration

<div class="termy">

```Python

Nothing to see here, plz disperse

```

## Run

<div class="termy">

```terminal
uvicorn run:sthalicrud --host 0.0.0.0 --port 9000
```
You could use <code>--reload</code>

## Automatic API docs

Now go to <a href="http://127.0.0.1:8000/docs" class="external-link" target="_blank">http://127.0.0.1:8000/docs</a>.

You will see the automatic interactive API documentation (provided by <a href="https://github.com/swagger-api/swagger-ui" class="external-link" target="_blank">Swagger UI</a>):

<!-- ![Swagger UI](https://fastapi.tiangolo.com/img/index/index-01-swagger-ui-simple.png) -->

### Alternative API docs

And now, go to <a href="http://127.0.0.1:8000/redoc" class="external-link" target="_blank">http://127.0.0.1:8000/redoc</a>.

You will see the alternative automatic documentation (provided by <a href="https://github.com/Rebilly/ReDoc" class="external-link" target="_blank">ReDoc</a>):

<!-- ![ReDoc](https://fastapi.tiangolo.com/img/index/index-02-redoc-simple.png) -->

## License

This project is licensed under the terms of the MIT license.

==> sthali-crud-0.0.3.1.tar.gz: sthali-crud-0.0.3.1/README.md <==
<p align="center">
    <a href="docs/images/crud.svg">
        <img src="docs/images/crud.svg" alt="SthaliCRUD" height=720>
    </a>
    <a href="https://pypi.org/project/sthali-crud" target="_blank">
        <img src="https://img.shields.io/pypi/v/sthali-crud?label=Version&color=%232EBC4F" alt="Package version">
    </a>
    <a href="https://pypi.org/project/sthali-crud" target="_blank">
        <img src="https://img.shields.io/pypi/pyversions/sthali-crud.svg?label=Python&color=%232EBC4F" alt="Supported Python versions">
    </a>
    <a href="https://pypi.org/project/sthali-crud" target="_blank">
        <img src="https://img.shields.io/github/license/jhunufernandes/sthali-crud?label=License&color=%232EBC4F" alt="License">
    </a>
    <a href="https://github.com/jhunufernandes/sthali-crud/actions/workflows/test-package.yml" target="_blank">
        <img src="https://github.com/jhunufernandes/sthali-crud/actions/workflows/test-package.yml/badge.svg" alt="Tests">
    </a>
    <a href="https://github.com/jhunufernandes/sthali-crud/actions/workflows/upload-package.yml" target="_blank">
        <img src="https://github.com/jhunufernandes/sthali-crud/actions/workflows/upload-package.yml/badge.svg" alt="Build">
    </a>
</p>

---

**PyPI**: <a href="https://pypi.org/project/sthali-crud/" target="_blank">https://pypi.org/project/sthali-crud/</a>

**Source Code**: <a href="https://github.com/jhunufernandes/sthali-crud" target="_blank">https://github.com/jhunufernandes/sthali-crud</a>

**Sthali Board**: <a href="https://github.com/users/jhunufernandes/projects/4" target="_blank">https://github.com/users/jhunufernandes/projects/4</a>

---

## Requirements

Python 3.11+

* <a href="https://fastapi.tiangolo.com/" class="external-link" target="_blank">FastAPI</a>
* <a href="https://tinydb.readthedocs.io/" class="external-link" target="_blank">TinyDB</a>

## Installation

<div class="termy">

```console
$ pip install sthali-crud
```

## Configuration

<div class="termy">

```Python

Nothing to see here, plz disperse

```

## Run

<div class="termy">

```terminal
uvicorn run:sthalicrud --host 0.0.0.0 --port 9000
```
You could use <code>--reload</code>

## Automatic API docs

Now go to <a href="http://127.0.0.1:8000/docs" class="external-link" target="_blank">http://127.0.0.1:8000/docs</a>.

You will see the automatic interactive API documentation (provided by <a href="https://github.com/swagger-api/swagger-ui" class="external-link" target="_blank">Swagger UI</a>):

<!-- ![Swagger UI](https://fastapi.tiangolo.com/img/index/index-01-swagger-ui-simple.png) -->

### Alternative API docs

And now, go to <a href="http://127.0.0.1:8000/redoc" class="external-link" target="_blank">http://127.0.0.1:8000/redoc</a>.

You will see the alternative automatic documentation (provided by <a href="https://github.com/Rebilly/ReDoc" class="external-link" target="_blank">ReDoc</a>):

<!-- ![ReDoc](https://fastapi.tiangolo.com/img/index/index-02-redoc-simple.png) -->

## License

This project is licensed under the terms of the MIT license.
